@@ -1,7 +1,7 @@
 from django.apps import apps
 from django.core.exceptions import ImproperlyConfigured, ValidationError
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 class BaseLink(object):
